==> jboss-eap-7.1.1-src.zip: jboss-eap-7.1-src/clustering/singleton/extension/src/main/java/org/wildfly/extension/clustering/singleton/SingletonServiceNameFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.extension.clustering.singleton;

import org.jboss.as.clustering.controller.DefaultableUnaryServiceNameFactoryProvider;
import org.jboss.as.clustering.controller.RequirementServiceNameFactory;
import org.jboss.as.clustering.controller.ServiceNameFactory;
import org.jboss.as.clustering.controller.UnaryRequirementServiceNameFactory;
import org.jboss.as.clustering.controller.UnaryServiceNameFactory;
import org.wildfly.clustering.service.DefaultableUnaryRequirement;
import org.wildfly.clustering.singleton.SingletonRequirement;

/**
 * @author Paul Ferraro
 */
public enum SingletonServiceNameFactory implements DefaultableUnaryServiceNameFactoryProvider {
    SINGLETON_POLICY(SingletonRequirement.SINGLETON_POLICY)
    ;
    private final UnaryServiceNameFactory factory;
    private final ServiceNameFactory defaultFactory;

    SingletonServiceNameFactory(DefaultableUnaryRequirement requirement) {
        this.factory = new UnaryRequirementServiceNameFactory(requirement);
        this.defaultFactory = new RequirementServiceNameFactory(requirement.getDefaultRequirement());
    }

    @Override
    public UnaryServiceNameFactory getServiceNameFactory() {
        return this.factory;
    }

    @Override
    public ServiceNameFactory getDefaultServiceNameFactory() {
        return this.defaultFactory;
    }
}

==> jboss-eap-7.3.4-src.zip: jboss-eap-7.3-src/clustering/singleton/extension/src/main/java/org/wildfly/extension/clustering/singleton/SingletonServiceNameFactory.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.extension.clustering.singleton;

import org.jboss.as.clustering.controller.DefaultableUnaryServiceNameFactoryProvider;
import org.jboss.as.clustering.controller.RequirementServiceNameFactory;
import org.jboss.as.clustering.controller.ServiceNameFactory;
import org.jboss.as.clustering.controller.UnaryRequirementServiceNameFactory;
import org.jboss.as.clustering.controller.UnaryServiceNameFactory;
import org.wildfly.clustering.service.DefaultableUnaryRequirement;
import org.wildfly.clustering.singleton.SingletonRequirement;

/**
 * @author Paul Ferraro
 */
public enum SingletonServiceNameFactory implements DefaultableUnaryServiceNameFactoryProvider {
    @Deprecated LEGACY_SINGLETON_POLICY(SingletonRequirement.SINGLETON_POLICY),
    SINGLETON_POLICY(SingletonRequirement.POLICY),
    ;
    private final UnaryServiceNameFactory factory;
    private final ServiceNameFactory defaultFactory;

    SingletonServiceNameFactory(DefaultableUnaryRequirement requirement) {
        this.factory = new UnaryRequirementServiceNameFactory(requirement);
        this.defaultFactory = new RequirementServiceNameFactory(requirement.getDefaultRequirement());
    }

    @Override
    public UnaryServiceNameFactory getServiceNameFactory() {
        return this.factory;
    }

    @Override
    public ServiceNameFactory getDefaultServiceNameFactory() {
        return this.defaultFactory;
    }
}
